summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/kpilotConfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/kpilotConfig.h')
-rw-r--r--kpilot/kpilot/kpilotConfig.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kpilot/kpilot/kpilotConfig.h b/kpilot/kpilot/kpilotConfig.h
index 6b260bf7..bc15c0ac 100644
--- a/kpilot/kpilot/kpilotConfig.h
+++ b/kpilot/kpilot/kpilotConfig.h
@@ -50,16 +50,16 @@ public:
} RunMode;
/**
* @return QString of default path for the BackupDB files
* are located
*/
- static QString getDefaultDBPath();
+ static TQString getDefaultDBPath();
// Conduit configuration information
- static void addDirtyDatabase(QString db);
- static void addAppBlockChangedDatabase(QString db);
- static void addFlagsChangedDatabase(QString db);
+ static void addDirtyDatabase(TQString db);
+ static void addAppBlockChangedDatabase(TQString db);
+ static void addFlagsChangedDatabase(TQString db);
/**
* This number can be changed every time a new
@@ -89,7 +89,7 @@ public:
* admonition to run kpilot in config mode to fix this.
* sorryVersionOutdated() uses KMessageBox to display it.
*/
- static QString versionDetails(int fileversion, bool run);
+ static TQString versionDetails(int fileversion, bool run);
static void sorryVersionOutdated(int fileversion);
/**
* Update the config file as best we can, and inform the user.
@@ -116,7 +116,7 @@ public:
* Returns the user's preference for the system-wide
* fixed font.
*/
- static const QFont& fixed() ;
+ static const TQFont& fixed() ;
static void sync();
} ;
@@ -50,16 +50,16 @@ public:
} RunMode;
/**
- * @return QString of default path for the BackupDB files
+ * @return TQString of default path for the BackupDB files
* are located
*/